
%**************************************************************************
% Programm nlms_demo_main
%
% Author:              Gerhard Schmidt, CAU Digital Signal Processing and
%                      System Theory
% Date of generation:  December, 26, 2005
% Project:             nlms_demo
%
% 
% Input: 
%
% Output:               ---
%
%**************************************************************************


%******************************************************************
% Set path to subdirectories
%******************************************************************
 
addpath([pwd,'/subfunctions']);
addpath([pwd,'/images']);

%******************************************************************
% Main data_struct
%******************************************************************

dim.main_fig.orig_x                        =   12;
dim.main_fig.orig_y                        =   45;
dim.main_fig.width                         = 1000;
dim.main_fig.height                        =  670;
dim.main_fig.space_lr                      =   30; 
dim.main_fig.space_tb                      =   30;
dim.main_fig.af_logo.width                 =  342;
dim.main_fig.af_logo.height                =   48;
dim.main_fig.low_frame.height              =   48;
dim.main_fig.low_frame.button.width        =  160;
dim.main_fig.low_frame.button.height       =   32;
dim.main_fig.low_frame.button.delta_w      =   30;
dim.main_fig.left_frame.width.small        =  200;
dim.main_fig.left_frame.width.large        =  700;
dim.main_fig.left_frame.space_lr           =   10;
dim.main_fig.left_frame.space_lr_sm        =   10;
dim.main_fig.left_frame.space_tb           =   10;
dim.main_fig.left_frame.space_tb_sm        =    2;
dim.main_fig.left_frame.button.height      =   25;
dim.main_fig.left_frame.button.text_offset =    4;
dim.main_fig.axes.space_left               =   60;
dim.main_fig.axes.space_bottom             =   30;
dim.main_fig.axes.space_delta              =   16;

fonts.normal.size      =  9;
fonts.upper_frame.size = 12;
fonts.small.size       =  9;

main_data.system.length        = 20;
main_data.system.h             = [0.08 -0.23 0.8 -0.7 0.3 -0.2 0.5 -0.35 -0.22 0.1 -0.17 0.11 -0.18 0.39 -0.09 0.14 0.08 -0.07 0.04 -0.07]';
main_data.system.x             = zeros(main_data.system.length,1);
main_data.system.snr_db        = 30;
main_data.system.n             = 0;
main_data.system.y             = 0;
main_data.system.sm_const_pow  = 0.9;
main_data.system.p_x           = 0;
main_data.system.p_y           = 0;
main_data.system.p_e           = 0;
main_data.adap_filter.length   = 20;
main_data.adap_filter.h        = zeros(main_data.adap_filter.length,1);
main_data.adap_filter.x        = zeros(main_data.adap_filter.length,1);
main_data.adap_filter.stepsize = 1;
main_data.adap_filter.e        = 0;

main_data.axes_top.plot_method            = 'bar_h_hat_h';
main_data.axes_top.plot_handle_1          = 0;
main_data.axes_top.plot_handle_2          = 0;
main_data.axes_top.update_flag_h          = 0;
main_data.axes_top.index                  = 0;
main_data.axes_top.plot_method_changed    = 0;
main_data.axes_bottom.plot_method         = 'sys_dist';
main_data.axes_bottom.plot_handle_1       = 0;
main_data.axes_bottom.plot_handle_2       = 0;
main_data.axes_bottom.update_flag_h       = 0;
main_data.axes_bottom.index               = 0;
main_data.axes_bottom.plot_method_changed = 0;

main_data.sim_active = 0;

%******************************************************************
% User interface
%******************************************************************

load nlms_demo_main;

a = figure('Units','pixels', ...
           'Color',[0.85 0.85 0.85], ...
           'Colormap',mat0, ...
           'Name','Adaptive Filters - Demo NLMS Algorithm', ...         
	       'NumberTitle','off', ...
           'PointerShapeCData',mat1, ...
	       'Position',[dim.main_fig.orig_x dim.main_fig.orig_y dim.main_fig.width dim.main_fig.height], ...
           'UserData',main_data, ...
           'Tag','demo_nlms_main_fig');                  
      
%******************************************************************
% Title frame
%******************************************************************       
          
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ... 
         'CreateFcn','image(logo_adaptive_filters); axis tight; set(gca,''XTick'',[],''YTick'',[]);', ...
	     'Position',[dim.main_fig.space_lr dim.main_fig.height-dim.main_fig.space_tb-dim.main_fig.af_logo.height dim.main_fig.af_logo.width dim.main_fig.af_logo.height], ...
	     'Tag','demo_nlms_axes_logo');

b = uicontrol('Parent',a, ...                       
	          'Units','pixels', ...                   
	          'BackgroundColor',[0.9 0.9 0.9], ...   
              'Position',[dim.main_fig.af_logo.width+(2*dim.main_fig.space_lr) dim.main_fig.height-dim.main_fig.space_tb-dim.main_fig.af_logo.height dim.main_fig.width-(3*dim.main_fig.space_lr)-dim.main_fig.af_logo.width dim.main_fig.af_logo.height], ...
	          'Style','frame', ...
              'Tag','demo_nlms_uppper_fraime'); 
                                                      
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.9 0.9 0.9], ...   
	          'HorizontalAlignment','center', ...
              'FontWeight','bold', ...
              'FontSize',fonts.upper_frame.size, ...
	          'Position',[dim.main_fig.af_logo.width+(2*dim.main_fig.space_lr)+5 dim.main_fig.height-dim.main_fig.space_tb-dim.main_fig.af_logo.height+12 dim.main_fig.width-(3*dim.main_fig.space_lr)-dim.main_fig.af_logo.width-10 20], ...
	          'String','Demo - NLMS Algorithm', ...
	          'Style','text');  
                   
%******************************************************************
% Left frame (visible)
%******************************************************************    
                        
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.9 0.9 0.9], ...   
              'Position',[dim.main_fig.space_lr (2*dim.main_fig.space_tb)+dim.main_fig.af_logo.height dim.main_fig.left_frame.width.small dim.main_fig.height-(4*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.low_frame.height ], ...
	          'Style','frame', ...
              'Tag','demo_nlms_main_left_frame');           
                    
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.left_frame.space_tb-dim.main_fig.left_frame.button.height round((dim.main_fig.left_frame.width.small-(3*dim.main_fig.left_frame.space_lr))/2) dim.main_fig.left_frame.button.height], ...  
              'Callback','dn_reduce_frame_left(dim)', ...             
	          'String','<<', ...
              'TooltipString','Hides a picture that shows the structure of the algorithm.',...
              'FontWeight','bold', ...   
              'Tag','demo_nlms_reduce_left_frame');

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.space_lr+round((dim.main_fig.left_frame.width.small+dim.main_fig.left_frame.space_lr)/2) dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.left_frame.space_tb-dim.main_fig.left_frame.button.height round((dim.main_fig.left_frame.width.small-(3*dim.main_fig.left_frame.space_lr))/2) dim.main_fig.left_frame.button.height], ...  
              'Callback','dn_enlarge_frame_left(dim);', ...             
	          'String','>>', ...
              'TooltipString','Shows a picture that depicts the structure of the algorithm.',...
              'FontWeight','bold', ...   
              'Tag','demo_nlms_enlarge_left_frame');          

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(4*dim.main_fig.left_frame.space_tb)-(4*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (3*dim.main_fig.left_frame.button.height)+(3*dim.main_fig.left_frame.space_tb_sm)+dim.main_fig.left_frame.space_tb], ...
	          'Style','frame', ...
              'Tag','demo_nlms_main_left_frame_visualizations');            
              
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(3*dim.main_fig.left_frame.space_tb)-(2*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Visualizations:', ...
	          'Tag','demo_nlms_main_left_frame_text_visualization', ...
              'Style','text');            
                           
b = uicontrol('Parent',a, ...               
              'Units','pixels', ...                                
              'BackgroundColor',[1 1 1], ...    
              'String',{'Plot 1: Impulse res. (bars)','Plot 1: Impulse res. (lines)'}, ...
              'FontWeight','bold', ...
              'Value',1, ...
              'HorizontalAlignment','right', ...
              'Callback','x=get(gco,''Value''); main_data = get(gcf,''UserData''); if (x == 1), main_data.axes_top.plot_method = ''bar_h_hat_h''; else, main_data.axes_top.plot_method  = ''line_h_hat_h''; end; main_data.axes_top.plot_method_changed = 1; set(gcf,''UserData'',main_data);', ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(3*dim.main_fig.left_frame.space_tb)-dim.main_fig.left_frame.space_tb_sm-(3*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height], ...
              'TooltipString','Selects the type of visualisation showed in the upper diagram.',...
              'Style','popupmenu', ...  
              'Tag','demp_nlms_main_left_frame_plot_axes_top');

b = uicontrol('Parent',a, ...               
              'Units','pixels', ...                                
              'BackgroundColor',[1 1 1], ...    
              'String',{'Plot 2: System distance','Plot 2: Short-term powers'}, ...
              'FontWeight','bold', ...
              'Value',1, ...
              'HorizontalAlignment','right', ...
              'Callback','x=get(gco,''Value''); main_data = get(gcf,''UserData''); if (x==1), main_data.axes_bottom.plot_method = ''sys_dist''; else, main_data.axes_bottom.plot_method = ''short_term_power'';end; main_data.axes_bottom.plot_method_changed = 1; set(gcf,''UserData'',main_data);', ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(3*dim.main_fig.left_frame.space_tb)-(2*dim.main_fig.left_frame.space_tb_sm)-(4*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height], ...
              'TooltipString','Selects the type of visualisation showed in the lower diagram.',...
              'Style','popupmenu', ...  
              'Tag','demp_nlms_main_left_frame_plot_axes_bottom');          

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(6*dim.main_fig.left_frame.space_tb)-(2*dim.main_fig.left_frame.space_tb_sm)-(8*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (4*dim.main_fig.left_frame.button.height)+dim.main_fig.left_frame.space_tb+(2*dim.main_fig.left_frame.space_tb_sm)], ...
	          'Style','frame', ...
              'Tag','demo_nlms_main_left_frame_visualizations');           
              
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(5*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Signals:', ...
	          'Tag','demo_nlms_main_left_frame_text_signals', ...
              'Style','text');    
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(6*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Excitation:', ...
	          'Tag','demo_nlms_main_left_frame_text_signals_excitation_left', ...
              'Style','text');
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(6*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','white noise', ...
	          'Tag','demo_nlms_main_left_frame_text_signals_excitation_right', ...
              'Style','text');              

b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(7*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Noise:', ...
	          'Tag','demo_nlms_main_left_frame_text_signals_noise_left', ...
              'Style','text');
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(7*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','white noise', ...
	          'Tag','demo_nlms_main_left_frame_text_signals_noise_right', ...
              'Style','text'); 
                        
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(8*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','SNR:', ...
	          'Tag','demo_nlms_main_left_frame_text_signals_snr_left', ...
              'Style','text');
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[1 1 1], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
              'Callback','str = get(gco,''String''); if (strcmp(str(end-1:end),''dB'') || (strcmp(str(end-1:end),''db''))),str=str(1:end-2);end;main_data = get(gcf,''UserData''); main_data.system.snr_db = str2num(str); main_data.axes_bottom.plot_method_changed = 1; set(gcf,''UserData'',main_data);', ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(8*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String',[num2str(main_data.system.snr_db),' dB'], ...
	          'Tag','demo_nlms_main_left_frame_edit_signals_snr_right', ...
              'Style','edit');                                        
              
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(9*dim.main_fig.left_frame.space_tb)-(2*dim.main_fig.left_frame.space_tb_sm)-(10*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (2*dim.main_fig.left_frame.button.height)+(2*dim.main_fig.left_frame.space_tb)], ...
	          'Style','frame', ...
              'Tag','demo_nlms_main_left_frame_control_para');   
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(7*dim.main_fig.left_frame.space_tb)-(9*dim.main_fig.left_frame.button.height)-(5*dim.main_fig.left_frame.space_tb_sm) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Control parameters:', ...
	          'Tag','demo_nlms_main_left_frame_text_control_parameters', ...
              'Style','text');            

b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(7*dim.main_fig.left_frame.space_tb)-(10*dim.main_fig.left_frame.button.height)-(5*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Step size:', ...
	          'Tag','demo_nlms_main_left_frame_text_con_para_step_size_left', ...
              'Style','text');   

b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[1 1 1], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(7*dim.main_fig.left_frame.space_tb)-(10*dim.main_fig.left_frame.button.height)-(5*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String',num2str(main_data.adap_filter.stepsize), ...
              'Callback','main_data = get(gcf,''UserData''); main_data.adap_filter.stepsize = str2num(get(gco,''String'')); set(gcf,''UserData'',main_data);', ...
	          'Tag','demo_nlms_main_left_frame_edit_con_para_step_size_right', ...
              'Style','edit');           
                                                                                                                                                       
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr (2*dim.main_fig.space_tb)+dim.main_fig.low_frame.height+dim.main_fig.left_frame.space_tb dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (3*dim.main_fig.left_frame.button.height)+(3*dim.main_fig.left_frame.space_tb_sm)+dim.main_fig.left_frame.space_tb], ...
	          'Style','frame', ...
              'Tag','demo_nlms_main_left_frame_buttons');      
         
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm (2*dim.main_fig.space_tb)+dim.main_fig.low_frame.height+(2*dim.main_fig.left_frame.space_tb)+(2*dim.main_fig.left_frame.button.height)+(2*dim.main_fig.left_frame.space_tb_sm) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Changes:', ...
	          'Tag','demo_nlms_main_left_frame_text_changes', ...
              'Style','text');    
          
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm (2*dim.main_fig.space_tb)+dim.main_fig.low_frame.height+(2*dim.main_fig.left_frame.space_tb)+dim.main_fig.left_frame.button.height+dim.main_fig.left_frame.space_tb_sm dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height], ...  
              'Callback','main_data = get(gcf,''UserData''); main_data.system.h = -main_data.system.h; main_data.axes_top.update_flag_h = 1; main_data.axes_bottom.update_flag_h = 1; set(gcf,''UserData'',main_data);', ...             
	          'String','Change signs (system)', ...
              'TooltipString','Alternates the sign of each coefficient of the unknown system.',...
              'FontWeight','bold', ...   
              'Tag','demo_nlms_left_frame_change_sign_lem');                 
              
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm (2*dim.main_fig.space_tb)+dim.main_fig.low_frame.height+(2*dim.main_fig.left_frame.space_tb) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height], ...  
              'Callback','main_data = get(gcf,''UserData''); main_data.adap_filter.h = main_data.adap_filter.h * 0; set(gcf,''UserData'',main_data);', ...             
	          'String','Reset the adaptive filter', ...
              'TooltipString','Sets each coefficient of the adaptive filter to zero.',...
              'FontWeight','bold', ...   
              'Tag','demo_nlms_left_frame_reset_adaptive_filter');          

%******************************************************************
% Left frame (hidden)
%******************************************************************              
 
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
         'Visible','off', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ... 
         'CreateFcn','set(gca,''XTick'',[],''YTick'',[]);', ...         
	     'Position',[2*dim.main_fig.space_lr+dim.main_fig.left_frame.width.small  (2*dim.main_fig.space_tb)+dim.main_fig.af_logo.height 1 dim.main_fig.height-(4*dim.main_fig.space_tb)-(2*dim.main_fig.af_logo.height)], ...
	     'Tag','demo_nlms_axes_hidden'); 

%******************************************************************
% Main axes (top)
%******************************************************************              
          
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ...     
	     'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.width.small+dim.main_fig.axes.space_left round(dim.main_fig.height/2)+dim.main_fig.axes.space_bottom+round(dim.main_fig.axes.space_delta/2)  dim.main_fig.width-(2*dim.main_fig.space_lr)-dim.main_fig.left_frame.width.small-dim.main_fig.axes.space_left dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-round(dim.main_fig.height/2)-dim.main_fig.axes.space_bottom-round(dim.main_fig.axes.space_delta/2)], ...
	     'Tag','demo_nlms_axes_top');              

dn_plot_init(1);     
                  
%******************************************************************
% Main axes (bottom)
%******************************************************************     
     
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ...      
	     'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.width.small+dim.main_fig.axes.space_left (2*dim.main_fig.space_tb)+dim.main_fig.low_frame.height+dim.main_fig.axes.space_bottom  dim.main_fig.width-(2*dim.main_fig.space_lr)-dim.main_fig.left_frame.width.small-dim.main_fig.axes.space_left round(dim.main_fig.height/2)-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.axes.space_bottom-round(dim.main_fig.axes.space_delta/2)], ...
	     'Tag','demo_nlms_axes_bottom');                                     

dn_plot_init(2);    
         
%******************************************************************
% Lower frame
%******************************************************************    
                        
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.9 0.9 0.9], ...   
              'Position',[dim.main_fig.space_lr dim.main_fig.space_tb dim.main_fig.width-(2*dim.main_fig.space_lr) dim.main_fig.low_frame.height], ...
	          'Style','frame', ...
              'Tag','demo_nlms_lower_frame');           
          
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.width-dim.main_fig.space_lr-dim.main_fig.low_frame.button.delta_w-dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...  
              'Callback','q_dlg = questdlg(''Do you really want to close the application?'',''Adaptive Filters - Demo NLMS Algorithm'',''Yes'',''No'',''Cancel'',''Yes''); if strcmp(q_dlg,''Yes''),close(gcf);end;', ...             
	          'String','Close', ...
              'FontWeight','bold', ... 
              'TooltipString','Click here to close the application!',...
              'Tag','demo_nlms_button_close');      
                    
b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+dim.main_fig.low_frame.button.delta_w dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','main_data = get(gcf,''UserData''); main_data.sim_active = 1; set(gcf,''UserData'',main_data);dn_start_sim;', ...
	          'String','Start', ...
              'FontWeight','bold', ...     
              'TooltipString','Starts the adaptation of the filter.',...
              'Tag','demo_nlms_button_start');  
          
b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+(2*dim.main_fig.low_frame.button.delta_w)+dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','main_data = get(gcf,''UserData''); main_data.sim_active = 0; set(gcf,''UserData'',main_data);', ...
	          'String','Stop', ...
              'FontWeight','bold', ...     
              'TooltipString','Stops the adaptation of the filter.',...
              'Tag','demo_nlms_button_stop');               
                  
% %******************************************************************
% % Allow resizing of the figure
% %******************************************************************          
%              
% ui_cons = findobj('Parent',a);
% for n = 1:length(ui_cons)
%     set(ui_cons(n),'Units','Normalized');
% end;
%           